@@ -15,7 +15,7 @@ __title__ = 'discord'
 __author__ = 'Rapptz'
 __license__ = 'MIT'
 __copyright__ = 'Copyright 2015-2019 Rapptz'
-__version__ = '1.1.1'
+__version__ = '1.2.3'
 
 from collections import namedtuple
 import logging
@@ -26,7 +26,7 @@ from .user import User, ClientUser, Profile
 from .emoji import Emoji, PartialEmoji
 from .activity import *
 from .channel import *
-from .guild import Guild
+from .guild import Guild, SystemChannelFlags
 from .relationship import Relationship
 from .member import Member, VoiceState
 from .message import Message, Attachment
@@ -53,7 +53,7 @@ from .raw_models import *
 
 VersionInfo = namedtuple('VersionInfo', 'major minor micro releaselevel serial')
 
-version_info = VersionInfo(major=1, minor=1, micro=1, releaselevel='final', serial=0)
+version_info = VersionInfo(major=1, minor=2, micro=3, releaselevel='final', serial=0)
 
 try:
     from logging import NullHandler
