@@ -54,7 +54,7 @@ class Reaction:
 
     Attributes
     -----------
-    emoji: :class:`Emoji` or :class:`str`
+    emoji: Union[:class:`Emoji`, :class:`str`]
         The reaction emoji. May be a custom emoji, or a unicode emoji.
     count: :class:`int`
         Number of times this reaction was made
@@ -99,7 +99,7 @@ class Reaction:
         Remove the reaction by the provided :class:`User` from the message.
 
         If the reaction is not your own (i.e. ``user`` parameter is not you) then
-        the :attr:`discord.permissions.Permissions.manage_messages` permission is needed.
+        the :attr:`~Permissions.manage_messages` permission is needed.
 
         The ``user`` parameter must represent a user or member and meet
         the :class:`abc.Snowflake` abc.
@@ -139,7 +139,7 @@ class Reaction:
         Flattening into a list: ::
 
             users = await reaction.users().flatten()
-            # users is now a list...
+            # users is now a list of User...
             winner = random.choice(users)
             await channel.send('{} has won the raffle.'.format(winner))
 
